//********************************************************
//*** MFCPaintBrush.cpp - MFC Tutorial Part 
//*** by Emil Vassev
//********************************************************
#include <afxwin.h> //**** this is the MFC library

/**
 * This class defines the application's window.
 */
class MFCTutorialWindow: public CFrameWnd
{
private:
    CPoint m_StartPoint, m_EndPoint;

public:
    MFCTutorialWindow()
    {
         Create(
             NULL, //**** use the default window properties for this window class
             _T("MFC Paint Brush"), //**** _T is generic text data type
             WS_OVERLAPPEDWINDOW, //**** full-featured window
             CRect( 200, 100, 550, 500 ) ); //**** screen coordinates
    };

public:
    void OnLButtonDown(UINT nFlags, CPoint point);
    void OnLButtonUp(UINT nFlags, CPoint point);
    DECLARE_MESSAGE_MAP();
};

//**** Message map macro
BEGIN_MESSAGE_MAP(MFCTutorialWindow, CFrameWnd)
      ON_WM_LBUTTONDOWN() //**** Macro to map the left button down msg to a handler
      ON_WM_LBUTTONUP()   //**** Macro to map the left button up msg to a handler
END_MESSAGE_MAP()

/**
 * Defines the handler of ON_WM_LBUTTONDOWN message. 
 */
void MFCTutorialWindow::OnLButtonDown(UINT nFlags, CPoint point) 
{
   CFrameWnd::OnLButtonDown(nFlags, point);
   m_StartPoint = point;
};

/**
 * Defines the handler of ON_WM_RBUTTONDOWN message. 
 */
void MFCTutorialWindow::OnLButtonUp(UINT nFlags, CPoint point) 
{
   CFrameWnd::OnRButtonDown(nFlags, point);

   m_EndPoint = point;
   CClientDC dc(this);
   dc.MoveTo(m_StartPoint);
   dc.LineTo(m_EndPoint);
};

/**
 * This class defines the windows application.
 * It defines the InitInstance member function.
 */
class MFCTutorialApp: public CWinApp
{
   MFCTutorialWindow *wnd; //**** pointer to the window
public:
   /**
    * Override InitInstance to initialize a new instance of your application running under Windows.
    */
   BOOL InitInstance()
   {
        wnd = new MFCTutorialWindow(); //**** create window
        m_pMainWnd = wnd; //**** this data member stores a pointer to our thread's main window object
        m_pMainWnd->ShowWindow(SW_SHOWNORMAL);

        return true; //**** report success
   }
};

MFCTutorialApp theApp; //**** instantiate the application


